import unittest
from unittest.mock import patch

from factory import SmsSenderFactory
from sender.aliyun_sender import AliyunSmsSender
from utils import generate_sms_code


class TestSmsSender(unittest.TestCase):
    @patch.object(AliyunSmsSender, 'send_sms', return_value={"status": "success"})
    def test_send_sms_success(self, mock_send_sms):
        # 创建工厂并生成 AliyunSmsSender 实例
        sender = SmsSenderFactory.create_sms_sender(
            provider="aliyun",
            access_key_id="test_id",
            access_key_secret="test_secret",
            sign_name="test_sign",
        )
        print(sender)
        # 测试发送短信
        # response = sender.send_sms("1234567890", 'verification', generate_sms_code())



from setuptools import setup, find_packages

setup(
    name="sms_send_cjh",
    version="0.1",
    packages=find_packages(),
    long_description=open('README.md').read(),  # 读取 README 文件作为包描述
    long_description_content_type='text/markdown',
    install_requires=[
        "aliyun-python-sdk-core",
        "aliyun-python-sdk-dysmsapi",
    ],
    description="发送短信包",
    author="CJH",
    author_email="942130598@qq.com",
    url="https://github.com/chongjiahao223/sms_sender.git"
)